TimeColumnController class

Constructors

TimeColumnController({int initialValue = 0, required int minValue, required int maxValue})
Create a controller with an initial value

Properties

hashCode int
The hash code for this object.
no setterinherited
maxValue int
final
minValue int
Min and max allowed values
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController FixedExtentScrollController
Scroll controller for the list wheel
final
value int
Current value of the column
getter/setter pair
valueNotifier ValueNotifier<int>
Notifies listeners when value changes
final

Methods

animateTo(int value, {required Duration duration, required Curve curve}) Future<void>
Animate to a specific value
dispose() → void
Dispose resources
jumpTo(int value) → void
Jump to a specific value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateValueFromScrollPosition(int position) → void
Update value from scroll position

Operators

operator ==(Object other) bool
The equality operator.
inherited