TimeDurationPicker class

Inheritance

Constructors

TimeDurationPicker({Key? key, required List<TimeColumnConfig> columns, double height = 168, double columnSpacing = 12.0, TimeDurationPickerTheme theme = const TimeDurationPickerTheme(), dynamic onChanged(List<int> values)?, bool showSeparatorLines = true, double? upperLinePosition, double? lowerLinePosition, double? width})
const

Properties

columns List<TimeColumnConfig>
List of column configurations that define the picker structure
final
columnSpacing double
Spacing between columns
final
hashCode int
The hash code for this object.
no setterinherited
height double
Height of the picker widget
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lowerLinePosition double?
final
onChanged → dynamic Function(List<int> values)?
Callback when time values change
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSeparatorLines bool
Show separator lines
final
theme TimeDurationPickerTheme
Theme for the time picker
final
upperLinePosition double?
Position of separator lines
final
width double?
Width of the picker
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TimeDurationPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited