TimeDurationPickerTheme class
Constructors
- TimeDurationPickerTheme({double itemExtent = 55, TextStyle selectedTextStyle = const TextStyle(fontSize: 20, fontWeight: FontWeight.w500, color: Colors.black), TextStyle unselectedTextStyle = const TextStyle(fontSize: 20, fontWeight: FontWeight.w500, color: Color(0x2E757575)), TextStyle separatorTextStyle = const TextStyle(fontSize: 20, fontWeight: FontWeight.w500, color: Colors.black), Color separatorColor = Colors.black})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemExtent → double
-
Height of each item in the wheel
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTextStyle → TextStyle
-
Text style for selected items
final
- separatorColor → Color
-
Color of separator lines
final
- separatorTextStyle → TextStyle
-
Text style for separator items
final
- unselectedTextStyle → TextStyle
-
Text style for unselected items
final
Methods
-
copyWith(
{double? itemExtent, TextStyle? selectedTextStyle, TextStyle? unselectedTextStyle, TextStyle? separatorTextStyle, Color? separatorColor}) → TimeDurationPickerTheme - Create a copy of this theme with some properties replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited